==> google_applovin_unity_ads-1.0.1.tar.gz: android/src/main/kotlin/com/btcpiyush/ads/google_applovin_unity_ads/native_ad/Controller.kt <==
package com.btcpiyush.ads.google_applovin_unity_ads.native_ad

import android.content.Context
import android.util.Log
import android.widget.FrameLayout
import com.applovin.mediation.MaxAd
import com.applovin.mediation.nativeAds.MaxNativeAdView
import com.google.android.gms.ads.nativead.NativeAd
import io.flutter.plugin.common.BinaryMessenger
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import com.facebook.ads.NativeAd as FBNativeAd

class NativeAdController(
        val id: String,
        val channel: MethodChannel,
        val context: Context
) : MethodChannel.MethodCallHandler {

    var appLovinNativeAd: MaxAd? = null
    var appLovinNativeAdView: MaxNativeAdView? = null
    var nativeAdView: FrameLayout? = null
    var nativeAd: NativeAd? = null
    var nativeAdFacebook: FBNativeAd? = null

    var loadRequested: ((MethodChannel.Result) -> Unit)? = null

    init {
        channel.setMethodCallHandler(this)
        Log.e("MainActivity", "NativeAdController Init")
    }

    override fun onMethodCall(call: MethodCall, result: MethodChannel.Result) {
        Log.e( "onMethodCall: ", "In Controller ${call.method}")
        when (call.method) {
            "load.ads.native" -> {
                channel.invokeMethod("loading", null)
                loadRequested?.let { it(result) }
            }
            else -> result.notImplemented()
        }
    }
}

object NativeAdControllerManager {
    private val controllers: ArrayList<NativeAdController> = arrayListOf()

    init {
         Log.e("MainActivity", "NativeAdControllerManager Init")
    }

    fun createController(id: String, binaryMessenger: BinaryMessenger, context: Context) {
        Log.e( "AppLovinctrolr  : ", " NativeAdControllerManager  Create Controller ------- ")
        if (getController(id) == null) {
            Log.e( "AppLovinctrolr  : ", " NativeAdControllerManager  Create Controller    Is Not Null------- ")
            val methodChannel = MethodChannel(binaryMessenger, id)
            Log.e( "AppLovinctrolr  : ", " NativeAdControllerManager  $methodChannel Create Controller    Is Not Null------- ")
            val controller = NativeAdController(id, methodChannel, context)
            controllers.add(controller)
        }
    }

    fun getController(id: String): NativeAdController? {
        return controllers.firstOrNull { it.id == id }
    }

    fun removeController(id: String) {
        Log.e( "AppLovinctrolr  : ", " NativeAdControllerManager  removeController ------- ")
        val index = controllers.indexOfFirst { it.id == id }
        if (index >= 0) controllers.removeAt(index)
    }
}

==> google_applovin_unity_ads-1.1.3.tar.gz: android/src/main/kotlin/com/btcpiyush/ads/google_applovin_unity_ads/native_ad/Controller.kt <==
package com.btcpiyush.ads.google_applovin_unity_ads.native_ad

import android.content.Context
import android.util.Log
import android.widget.FrameLayout
import com.applovin.mediation.MaxAd
import com.applovin.mediation.nativeAds.MaxNativeAdView
import com.applovin.sdk.AppLovinSdk
import com.google.android.gms.ads.nativead.NativeAd
import io.flutter.plugin.common.BinaryMessenger
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import com.facebook.ads.NativeAd as FBNativeAd

class NativeAdController(
        val appLovinSDK: AppLovinSdk?,
        val id: String,
        val channel: MethodChannel,
        val context: Context
) : MethodChannel.MethodCallHandler {

    var appLovinNativeAd: MaxAd? = null
    var appLovinNativeAdView: MaxNativeAdView? = null
    var nativeAdView: FrameLayout? = null
    var nativeAd: NativeAd? = null
    var nativeAdFacebook: FBNativeAd? = null

    var loadRequested: ((MethodChannel.Result) -> Unit)? = null

    init {
        channel.setMethodCallHandler(this)
        Log.e("MainActivity", "NativeAdController Init")
    }

    override fun onMethodCall(call: MethodCall, result: MethodChannel.Result) {
        Log.e( "onMethodCall: ", "In Controller ${call.method}")
        when (call.method) {
            "load.ads.native" -> {
                channel.invokeMethod("loading", null)
                loadRequested?.let { it(result) }
            }
            else -> result.notImplemented()
        }
    }
}

object NativeAdControllerManager {
    private val controllers: ArrayList<NativeAdController> = arrayListOf()

    init {
         Log.e("MainActivity", "NativeAdControllerManager Init")
    }

    fun createController(appLovinSDK: AppLovinSdk?, id: String, binaryMessenger: BinaryMessenger, context: Context) {
        Log.e( "AppLovinctrolr  : ", " NativeAdControllerManager  Create Controller ------- ")
        if (getController(id) == null) {
            Log.e( "AppLovinctrolr  : ", " NativeAdControllerManager  Create Controller    Is Not Null------- ")
            val methodChannel = MethodChannel(binaryMessenger, id)
            Log.e( "AppLovinctrolr  : ", " NativeAdControllerManager  $methodChannel Create Controller    Is Not Null------- ")
            val controller = NativeAdController(appLovinSDK,id, methodChannel, context)
            controllers.add(controller)
        }
    }

    fun getController(id: String): NativeAdController? {
        return controllers.firstOrNull { it.id == id }
    }

    fun removeController(id: String) {
        Log.e( "AppLovinctrolr  : ", " NativeAdControllerManager  removeController ------- ")
        val index = controllers.indexOfFirst { it.id == id }
        if (index >= 0) controllers.removeAt(index)
    }
}
